pub struct TsPluginBridge { /* private fields */ }Expand description
Bridge to existing TypeScript plugins.
Implementations
Sourceimpl TsPluginBridge
impl TsPluginBridge
Sourcepub fn with_address(self, address: impl Into<String>) -> Self
pub fn with_address(self, address: impl Into<String>) -> Self
Set a custom IPC address.
Sourcepub fn spawn_and_connect(&mut self) -> Result<(), PluginError>
pub fn spawn_and_connect(&mut self) -> Result<(), PluginError>
Spawn the TypeScript plugin host process and connect.
This looks for a plugin-host.js or plugin-host.ts entry point
in the plugins directory and runs it with Node.js or Bun.
Errors
Returns error if process spawn or connection fails.
Sourcepub fn is_running(&mut self) -> bool
pub fn is_running(&mut self) -> bool
Check if the host process is still running.
Sourcepub const fn skill_manifest(&self) -> Option<&SkillManifest>
pub const fn skill_manifest(&self) -> Option<&SkillManifest>
Get the cached skill manifest.
Sourcepub fn load_skills(&self) -> Result<SkillManifest, PluginError>
pub fn load_skills(&self) -> Result<SkillManifest, PluginError>
Sourcepub fn execute_tool(
&self,
name: &str,
params: Value,
) -> Result<Value, PluginError>
pub fn execute_tool( &self, name: &str, params: Value, ) -> Result<Value, PluginError>
Execute a tool registered by TypeScript plugin.
Errors
Returns error if not connected or tool execution fails.